==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/TASKPLANTOOLID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TASKPLANTOOLID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TASKPLANTOOLID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBPLANID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKPLANTOOLID_Type", propOrder = {
    "tasklistid",
    "toolid",
    "jobplanid"
})
public class TASKPLANTOOLID_Type {

    @XmlElement(name = "TASKLISTID", required = true)
    protected TASKLISTID_Type tasklistid;
    @XmlElement(name = "TOOLID", required = true)
    protected TOOLID toolid;
    @XmlElement(name = "JOBPLANID")
    protected TASKLISTID_Type jobplanid;

    /**
     * Obtient la valeur de la propriété tasklistid.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getTASKLISTID() {
        return tasklistid;
    }

    /**
     * Définit la valeur de la propriété tasklistid.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setTASKLISTID(TASKLISTID_Type value) {
        this.tasklistid = value;
    }

    /**
     * Obtient la valeur de la propriété toolid.
     * 
     * @return
     *     possible object is
     *     {@link TOOLID }
     *     
     */
    public TOOLID getTOOLID() {
        return toolid;
    }

    /**
     * Définit la valeur de la propriété toolid.
     * 
     * @param value
     *     allowed object is
     *     {@link TOOLID }
     *     
     */
    public void setTOOLID(TOOLID value) {
        this.toolid = value;
    }

    /**
     * Obtient la valeur de la propriété jobplanid.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getJOBPLANID() {
        return jobplanid;
    }

    /**
     * Définit la valeur de la propriété jobplanid.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setJOBPLANID(TASKLISTID_Type value) {
        this.jobplanid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/TASKPLANTOOLID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TASKPLANTOOLID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TASKPLANTOOLID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBPLANID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKPLANTOOLID_Type", propOrder = {
    "tasklistid",
    "toolid",
    "jobplanid"
})
public class TASKPLANTOOLID_Type {

    @XmlElement(name = "TASKLISTID", required = true)
    protected TASKLISTID_Type tasklistid;
    @XmlElement(name = "TOOLID", required = true)
    protected TOOLID toolid;
    @XmlElement(name = "JOBPLANID")
    protected TASKLISTID_Type jobplanid;

    /**
     * Gets the value of the tasklistid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getTASKLISTID() {
        return tasklistid;
    }

    /**
     * Sets the value of the tasklistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setTASKLISTID(TASKLISTID_Type value) {
        this.tasklistid = value;
    }

    /**
     * Gets the value of the toolid property.
     * 
     * @return
     *     possible object is
     *     {@link TOOLID }
     *     
     */
    public TOOLID getTOOLID() {
        return toolid;
    }

    /**
     * Sets the value of the toolid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TOOLID }
     *     
     */
    public void setTOOLID(TOOLID value) {
        this.toolid = value;
    }

    /**
     * Gets the value of the jobplanid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getJOBPLANID() {
        return jobplanid;
    }

    /**
     * Sets the value of the jobplanid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setJOBPLANID(TASKLISTID_Type value) {
        this.jobplanid = value;
    }

}
